@@ -1,3 +1,17 @@
+# Copyright 2019 Kemal Kurniawan
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 from functools import reduce
 from typing import List, Mapping, Sequence, Union
 
@@ -23,11 +37,17 @@ class Batch(Sequence[Sample]):
     def __len__(self) -> int:
         return len(self._samples)
 
-    def to_array(self, pad_with: int = 0) -> Mapping[FieldName, np.ndarray]:
+    def to_array(
+            self,
+            pad_with: Union[int, Mapping[FieldName, int]] = 0,
+    ) -> Mapping[FieldName, np.ndarray]:
         """Convert the batch into `~numpy.ndarray`.
 
         Args:
-            pad_with: Pad sequential field values with this number.
+            pad_with: Pad sequential field values with this number. Can
+                also be a mapping from field names to padding number for
+                that field. Fields whose name is not in the mapping will
+                be padded with zeros.
 
         Returns:
             A mapping from field names to `~numpy.ndarray` s whose first
@@ -36,8 +56,14 @@ class Batch(Sequence[Sample]):
         if not self._samples:
             return {}
 
+        field_names = self._samples[0].keys()
+
+        pad_dict = pad_with
+        if isinstance(pad_dict, int):
+            pad_dict = {name: pad_with for name in field_names}
+
         arr = {}
-        for name in self._samples[0].keys():
+        for name in field_names:
             values = self._get_values(name)
 
             # Get max length for all depths, 1st elem is batch size
@@ -47,7 +73,7 @@ class Batch(Sequence[Sample]):
                 raise ValueError(f"field '{name}' has inconsistent nesting depth")
 
             # Get padding for all depths
-            paddings = self._get_paddings(maxlens, pad_with)
+            paddings = self._get_paddings(maxlens, pad_dict.get(name, 0))
             # Pad the values
             data = self._pad(values, maxlens, paddings, 0)
 
